// -*-Mode: C++;-*- 
/*
 * $Id: compoundkeydlg.h,v 2.3 2001/04/14 10:56:03 ral Exp $
 */

#ifndef CCompoundKeyDlg_included
#define CCompoundKeyDlg_included

#include "compoundkeydata.h"
#include "tabledescr.h"

class CCompoundKeyDlg : public CCompoundKeyData
{
    Q_OBJECT

    ColumnList*int_col_list;
    KeyList*int_key_list;

protected slots:
    virtual void AddKey();
    virtual void KeyTextReturn();
    virtual void IndexSelected();
    virtual void DeleteKey();
    virtual void UniqueSelected();
    virtual void KeyFieldSelected(int);
    virtual void TableColumnsSelected(int);
    virtual void AddToKey();
    virtual void KeyColumnsSelected(int);
    virtual void KeyNameChanged(const QString&);
    virtual void PrimarySelected();
    virtual void RemoveFromKey();

public:
    CCompoundKeyDlg(QWidget* parent = NULL, const char* name = NULL);
    virtual ~CCompoundKeyDlg();
    
    virtual void set_Columns(ColumnList*col_list,KeyList*key_list);
private:
    CKeyDescriptor*CurrentKey;
};

#endif // CCompoundKeyDlg_included
